# do not import dios-stuff here


class Options:
    """storage class for the keys in ``dios_options``"""

    """Set the number of rows and variables to display in a call that use
    ``__repr__`` or ``__str__`` like e.g. ``print(dios)`` do."""
    disp_max_rows = "disp_max_rows "
    disp_max_vars = "disp_max_vars"

    """
    0: accept all
    1: accept if at least one keys is is in both DioS
    3: accept if both dios have the exact same keys (makes only sense for assignments with slicer,
      otherwise its the same than creating a new dios)"""
    dios_to_dios_method = "dios_to_dios_method"

    mixed_itype_policy = "mixed_itype_policy"


class OptionsDiosToDios:
    all_must_match = 'all'
    at_least_one = 'one'
    any_matching = 'any'


# set default values
dios_options = {
    Options.disp_max_rows: 10,
    Options.disp_max_vars: 4,
    Options.dios_to_dios_method: 3,
    Options.mixed_itype_policy: 'warn',
}


def get_dios_to_dios_keys(keys, other, method):

    err_append = "consider changing dios.option['dios_to_dios_method']"

    if method == OptionsDiosToDios.any_matching:
        keys = [k for k in keys if k in other.columns]

    elif method == OptionsDiosToDios.at_least_one:
        keys = [k for k in keys if k in other.columns]
        if not keys:
            raise KeyError("src-DioS and dest-DioS need to share at least one key, " + err_append)

    # elif method == 2:
    #     fail = [k for k in keys if k not in other.columns]
    #     if fail:
    #         raise KeyError(f"{fail} are missing in the destiny-dios, " + err_append)

    # keys in both dios's must be equal
    elif OptionsDiosToDios.all_must_match:
        fail = set(keys).symmetric_difference(set(other.columns))
        if fail:
            raise KeyError(f"{fail} is not in both of src- and dest-dios, " + err_append)

    else:
        raise ValueError(method)

    return keys
